use crate::{architecture::JlrArchitecture, did::Did};

#[derive(Clone, Debug)]
pub struct Ecu {
    pub name: String,
    pub acronym: String,
    pub address: [u8; 2],
    pub architecture: Vec<JlrArchitecture>,
}
#[derive(Debug)]
pub struct SnapshotEcu {
    pub name: String,
    pub acronym: String,
    pub address: [u8; 2],
    pub architecture: Vec<JlrArchitecture>,
    pub dids: Vec<Did>,
}

pub fn create_ecu_list() -> Vec<Ecu> {
    let list: Vec<Ecu> = vec![
        Ecu {
            name: "Audio Amplifier Module".to_string(),
            acronym: "AAM".to_string(),
            address: [0x17, 0xA4],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Active Aero Control Module".to_string(),
            acronym: "AACM".to_string(),
            address: [0x17, 0x11],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Anti-Lock Brake System Control Module".to_string(),
            acronym: "ABS".to_string(),
            address: [0x17, 0xE6],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Body Control Module A".to_string(),
            acronym: "BCMA".to_string(),
            address: [0x17, 0x26],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Body Control Module B".to_string(),
            acronym: "BCMB".to_string(),
            address: [0x17, 0xE3],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Brake System Control Module".to_string(),
            acronym: "BSCM".to_string(),
            address: [0x17, 0x56],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Front Active Roll Control Module".to_string(),
            acronym: "FARC".to_string(),
            address: [0x17, 0x02],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Chassis Control Module".to_string(),
            acronym: "CHCM".to_string(),
            address: [0x17, 0x10],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Rear Active Roll Control Module".to_string(),
            acronym: "RARC".to_string(),
            address: [0x17, 0x63],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Chassis Control Module B".to_string(),
            acronym: "CHCMB".to_string(),
            address: [0x17, 0x73],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Suspension Pump Control Module".to_string(),
            acronym: "SPCM".to_string(),
            address: [0x14, 0x90],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Driver Front Door Module".to_string(),
            acronym: "DDM".to_string(),
            address: [0x17, 0x40],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Driver Rear Door Module".to_string(),
            acronym: "DRDM".to_string(),
            address: [0x17, 0x42],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Driver Front Seat Module".to_string(),
            acronym: "DSM".to_string(),
            address: [0x17, 0x44],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Electrical Energy Storage Module".to_string(),
            acronym: "EESM".to_string(),
            address: [0x17, 0x73],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Exterior Handle NFC".to_string(),
            acronym: "EHNFC".to_string(),
            address: [0x17, 0x36],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Electronic Power Distribution Unit".to_string(),
            acronym: "EPDU".to_string(),
            address: [0x17, 0x91],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Electric Power Inverter Converter Control Module 'E'".to_string(),
            acronym: "EPICE".to_string(),
            address: [0x17, 0x46],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Exterior Stowage Box Module".to_string(),
            acronym: "ESBM".to_string(),
            address: [0x17, 0x47],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Headlamp Auxiliary Digital Module A".to_string(),
            acronym: "HADMA".to_string(),
            address: [0x14, 0xA4],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Headlamp Auxiliary Digital Module B".to_string(),
            acronym: "HADMB".to_string(),
            address: [0x14, 0xA5],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Headlamp Auxiliary Matrix Module A".to_string(),
            acronym: "HAMMA".to_string(),
            address: [0x14, 0xA0],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Headlamp Auxiliary Matrix Module B".to_string(),
            acronym: "HAMMB".to_string(),
            address: [0x14, 0xA1],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Headlamp Auxiliary Pixel Module A".to_string(),
            acronym: "HAPMA".to_string(),
            address: [0x14, 0xA2],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Headlamp Auxiliary Pixel Module B".to_string(),
            acronym: "HAPMB".to_string(),
            address: [0x14, 0xA3],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Headlamp Control Module A".to_string(),
            acronym: "HCMA".to_string(),
            address: [0x17, 0x34],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Headlamp Control Module B".to_string(),
            acronym: "HCMB".to_string(),
            address: [0x17, 0xC3],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Inverter Front".to_string(),
            acronym: "INVA".to_string(),
            address: [0x17, 0x42],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Inverter Rear".to_string(),
            acronym: "INVB".to_string(),
            address: [0x17, 0x43],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Inverter Rear Left".to_string(),
            acronym: "INVD".to_string(),
            address: [0x17, 0x44],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Near Field Sensing Module C".to_string(),
            acronym: "NFSMC".to_string(),
            address: [0x14, 0x03],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Restraints Occupant Classification System Module".to_string(),
            acronym: "OCS".to_string(),
            address: [0x17, 0x65],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Powernet Battery Unit".to_string(),
            acronym: "PBU".to_string(),
            address: [0x17, 0x77],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Passenger Front Door Module".to_string(),
            acronym: "PDM".to_string(),
            address: [0x17, 0x41],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Phone Key Controller Module".to_string(),
            acronym: "PKCM".to_string(),
            address: [0x17, 0x37],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Phone Key Satellite Module".to_string(),
            acronym: "PKSM".to_string(),
            address: [0x17, 0x12],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Phone Key Satellite Module 2".to_string(),
            acronym: "PKSM2".to_string(),
            address: [0x17, 0x13],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Phone Key Satellite Module 3".to_string(),
            acronym: "PKSM3".to_string(),
            address: [0x14, 0x14],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Phone Key Satellite Module 4".to_string(),
            acronym: "PKSM4".to_string(),
            address: [0x14, 0x15],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Phone Key Satellite Module 5".to_string(),
            acronym: "PKSM5".to_string(),
            address: [0x17, 0x17],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Phone Key Satellite Module B".to_string(),
            acronym: "PKSMB".to_string(),
            address: [0x17, 0x20],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Phone Key Satellite Module B2".to_string(),
            acronym: "PKSMB2".to_string(),
            address: [0x17, 0x21],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Phone Key Satellite Module C".to_string(),
            acronym: "PKSMC".to_string(),
            address: [0x14, 0x23],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Passenger Rear Door Module".to_string(),
            acronym: "PRDM".to_string(),
            address: [0x17, 0x43],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Power Steering Control Module".to_string(),
            acronym: "PSCM".to_string(),
            address: [0x17, 0x30],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Power Steering Control Module 'B'".to_string(),
            acronym: "PSCMB".to_string(),
            address: [0x14, 0x64],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Passenger Front Seat Module".to_string(),
            acronym: "PSM".to_string(),
            address: [0x17, 0xA3],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Running Board Control Module".to_string(),
            acronym: "RBM".to_string(),
            address: [0x17, 0x66],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        // Ecu {
        //     name: "Pyrotechnic Control Unit".to_string(),
        //     acronym: "AECA/PCU".to_string(),
        //     address: [0x17, 0xF1],
        //     architecture: [JlrArchitecture::Eva25].to_vec(),
        // },
        Ecu {
            name: "Restraints Control Module".to_string(),
            acronym: "RCM".to_string(),
            address: [0x17, 0x37],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Rear Differential Control Module".to_string(),
            acronym: "RDCM".to_string(),
            address: [0x17, 0x95],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Rear Gate / Trunk Module".to_string(),
            acronym: "RGTM".to_string(),
            address: [0x17, 0x75],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Rear Gate Trunk Module B".to_string(),
            acronym: "RGTMB".to_string(),
            address: [0x17, 0xB6],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Rear Left Seat Module".to_string(),
            acronym: "RLSM".to_string(),
            address: [0x17, 0x02],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Rear Right Seat Module".to_string(),
            acronym: "RRSM".to_string(),
            address: [0x17, 0x63],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Rear Wheel Steering Control Module".to_string(),
            acronym: "RSCM".to_string(),
            address: [0x14, 0x62],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Seatbelt Pretensioner Control Module 'A'".to_string(),
            acronym: "SPMA".to_string(),
            address: [0x17, 0xD1],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Seatbelt Pretensioner Control Module 'B'".to_string(),
            acronym: "SPMB".to_string(),
            address: [0x17, 0xD4],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Steering Wheel Auxiliary Module".to_string(),
            acronym: "SWAM".to_string(),
            address: [0x17, 0xF2],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Steering Wheel Module".to_string(),
            acronym: "SWM".to_string(),
            address: [0x17, 0xF5],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Steering Wheel Switch Left".to_string(),
            acronym: "SWSL".to_string(),
            address: [0x17, 0xF3],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Steering Wheel Switch Right".to_string(),
            acronym: "SWSR".to_string(),
            address: [0x17, 0xF4],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Transfer Case Control Module".to_string(),
            acronym: "TCCM".to_string(),
            address: [0x17, 0x61],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Transmission Control Module".to_string(),
            acronym: "TCM".to_string(),
            address: [0x17, 0xE1],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Wireless Device Charger Module".to_string(),
            acronym: "WDCM".to_string(),
            address: [0x17, 0x07],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Wireless Device Charger Module 'B'".to_string(),
            acronym: "WDCMB".to_string(),
            address: [0x14, 0xA7],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Wireless Device Charger Module B2".to_string(),
            acronym: "WDCMB2".to_string(),
            address: [0x14, 0xB0],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Wireless Device Charger Module C".to_string(),
            acronym: "WDCMC".to_string(),
            address: [0x17, 0x05],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Gateway Module".to_string(),
            acronym: "GWM".to_string(),
            address: [0x17, 0x16],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Powertrain Control Module".to_string(),
            acronym: "PCM".to_string(),
            address: [0x17, 0xE0],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Body Control Module".to_string(),
            acronym: "BCM".to_string(),
            address: [0x17, 0x26],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Battery Management Control Module".to_string(),
            acronym: "BMCM".to_string(),
            address: [0x17, 0xE5],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "Cruise Control Module".to_string(),
            acronym: "CCM".to_string(),
            address: [0x17, 0x64],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Driver Assistance Domain Controller".to_string(),
            acronym: "DADC".to_string(),
            address: [0x14, 0x16],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Gear Shift Module".to_string(),
            acronym: "GSM".to_string(),
            address: [0x17, 0x32],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Head Up Display".to_string(),
            acronym: "HUD".to_string(),
            address: [0x17, 0xB2],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Heating Ventilation & Air Conditioning".to_string(),
            acronym: "HVAC".to_string(),
            address: [0x17, 0x33],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Infotainment Compute Control Module".to_string(),
            acronym: "ICCM".to_string(),
            address: [0x14, 0xB4],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Infotainment Compute Control Module B".to_string(),
            acronym: "ICCMB".to_string(),
            address: [0x14, 0xB7],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Interactive Control Interface Module A".to_string(),
            acronym: "ICIMA_A".to_string(),
            address: [0x14, 0x52],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Interactive Display Module A".to_string(),
            acronym: "IDMA".to_string(),
            address: [0x17, 0xA2],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Infotainment Gateway Module".to_string(),
            acronym: "IGM".to_string(),
            address: [0x14, 0xB3],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Infotainment Gateway Module B".to_string(),
            acronym: "IGMB".to_string(),
            address: [0x14, 0xB5],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "Instrument Panel Cluster Control Module B".to_string(),
        //     acronym: "IPCB".to_string(),
        //     address: [0x14, 0xB2],
        //     architecture: [JlrArchitecture::Eva2].to_vec(),
        // },
        Ecu {
            name: "Image Processing Module A".to_string(),
            acronym: "IPMA".to_string(),
            address: [0x17, 0x06],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Left Interactive Display Module".to_string(),
            acronym: "LIDM".to_string(),
            address: [0x14, 0x60],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Near Field Sensing Module".to_string(),
            acronym: "NFSM".to_string(),
            address: [0x14, 0x34],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Remote Function Actuator".to_string(),
            acronym: "RFA".to_string(),
            address: [0x17, 0x31],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Rear Heating Ventilation & Air Conditioning".to_string(),
            acronym: "RHVAC".to_string(),
            address: [0x17, 0x85],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Right Interactive Display Module".to_string(),
            acronym: "RIDM".to_string(),
            address: [0x14, 0x61],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Steering Angle Sesnor Module".to_string(),
            acronym: "SASM".to_string(),
            address: [0x17, 0x97],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Starter Battery Unit".to_string(),
            acronym: "SBU".to_string(),
            address: [0x14, 0xE2],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Sunroof Control Module C".to_string(),
            acronym: "SCMC".to_string(),
            address: [0x17, 0x02],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Sunroof Control Module D".to_string(),
            acronym: "SCMD".to_string(),
            address: [0x17, 0x63],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Side Obstacle Detection Left".to_string(),
            acronym: "SODL".to_string(),
            address: [0x17, 0xC4],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "Side Obstacle Detection Right".to_string(),
            acronym: "SODR".to_string(),
            address: [0x17, 0xC6],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "APIM".to_string(),
            address: [0x17, 0xD0],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "ARCM".to_string(),
            address: [0x17, 0xD2],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "AVCM".to_string(),
        //     address: [0x17, 0x04],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "ADDW".to_string(),
        //     address: [0x14, 0x36],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "ASCC".to_string(),
        //     address: [0x14, 0x86],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "ATCM".to_string(),
            address: [0x17, 0x92],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "AWD".to_string(),
            address: [0x17, 0x03],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "AWDB".to_string(),
            address: [0x14, 0x33],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "ATIA".to_string(),
        //     address: [0x14, 0x80],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "ATIB".to_string(),
        //     address: [0x14, 0x81],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "ABS_760".to_string(),
        //     address: [0x17, 0x60],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "ACM".to_string(),
            address: [0x17, 0x27],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "AHCM".to_string(),
            address: [0x17, 0xE3],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "AUCM".to_string(),
            address: [0x17, 0xC7],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "BCCM".to_string(),
            address: [0x17, 0xE5],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "BCCMB".to_string(),
        //     address: [0x17, 0x45],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "BECM".to_string(),
            address: [0x17, 0xE4],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "BBM".to_string(),
            address: [0x17, 0xE2],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "CRTM".to_string(),
            address: [0x17, 0x62],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "CDMA".to_string(),
        //     address: [0x14, 0x25],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "CCCM".to_string(),
        //     address: [0x14, 0xF0],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "CHCMC".to_string(),
        //     address: [0x17, 0xC0],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "CDP".to_string(),
            address: [0x17, 0x70],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "CTAM".to_string(),
        //     address: [0x14, 0x83],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "CFLR".to_string(),
        //     address: [0x14, 0xC0],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "CFRR".to_string(),
        //     address: [0x14, 0xC1],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "CRLR".to_string(),
        //     address: [0x14, 0xC2],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "CRRR".to_string(),
        //     address: [0x14, 0xC3],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "DRLA".to_string(),
        //     address: [0x14, 0x84],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "DRLB".to_string(),
        //     address: [0x14, 0x85],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "DABM".to_string(),
            address: [0x17, 0xD6],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "DACMC".to_string(),
            address: [0x17, 0xD5],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "DDCM".to_string(),
            address: [0x14, 0x37],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "DADCA".to_string(),
        //     address: [0x14, 0xD2],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "DADCB".to_string(),
        //     address: [0x14, 0xD3],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "DADHA".to_string(),
        //     address: [0x14, 0xD5],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "DADHB".to_string(),
        //     address: [0x14, 0xD7],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "DADSA".to_string(),
        //     address: [0x14, 0xD4],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "DADSB".to_string(),
        //     address: [0x14, 0xD6],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "DHUD".to_string(),
        //     address: [0x14, 0xF4],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "EDDM".to_string(),
        //     address: [0x14, 0x76],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "EDPM".to_string(),
            address: [0x14, 0x45],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "EPIC".to_string(),
            address: [0x17, 0xE7],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "EPICB".to_string(),
            address: [0x17, 0x47],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "EPICB_NonOBD".to_string(),
        //     address: [0x17, 0x47],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "EPICC".to_string(),
        //     address: [0x17, 0x46],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "EPICD".to_string(),
            address: [0x17, 0x53],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "ESAM".to_string(),
        //     address: [0x14, 0x00],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "ESS".to_string(),
        //     address: [0x17, 0x25],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "FTCM".to_string(),
            address: [0x17, 0x87],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "FTCMB".to_string(),
            address: [0x17, 0x90],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FACM".to_string(),
        //     address: [0x14, 0x30],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FCIR".to_string(),
        //     address: [0x14, 0xE4],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FCL".to_string(),
        //     address: [0x14, 0xC4],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FCR".to_string(),
        //     address: [0x14, 0xC5],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FCCD".to_string(),
        //     address: [0x14, 0xF2],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FCD".to_string(),
        //     address: [0x14, 0xF1],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FCSP".to_string(),
        //     address: [0x14, 0x67],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "FCDIM".to_string(),
            address: [0x17, 0xA5],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "FCIM".to_string(),
            address: [0x17, 0xA7],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "FCIMB".to_string(),
            address: [0x17, 0xA0],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "FCIMC".to_string(),
            address: [0x17, 0xA1],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FDSM".to_string(),
        //     address: [0x17, 0x93],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FDD".to_string(),
        //     address: [0x14, 0xF3],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "FEM".to_string(),
            address: [0x17, 0x67],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FLPSD".to_string(),
        //     address: [0x14, 0x02],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FLM".to_string(),
        //     address: [0x17, 0x96],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FMPU".to_string(),
        //     address: [0x14, 0x42],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FODL".to_string(),
        //     address: [0x14, 0x40],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FODR".to_string(),
        //     address: [0x14, 0x41],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FPD".to_string(),
        //     address: [0x14, 0x93],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "FRPSD".to_string(),
        //     address: [0x14, 0x24],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "GSMB".to_string(),
            address: [0x17, 0x11],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "GPSM".to_string(),
            address: [0x17, 0x01],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "HSPM".to_string(),
        //     address: [0x14, 0x92],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "HUDB".to_string(),
        //     address: [0x14, 0xB6],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "HCM".to_string(),
            address: [0x17, 0x34],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "HVCCM".to_string(),
            address: [0x14, 0x75],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "IPMB".to_string(),
            address: [0x17, 0xB1],
            architecture: [].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "IPMC".to_string(),
        //     address: [0x14, 0x54],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "ICS".to_string(),
            address: [0x17, 0x94],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "IMU".to_string(),
        //     address: [0x14, 0xA6],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "ICM".to_string(),
            address: [0x17, 0x84],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "IMC".to_string(),
            address: [0x17, 0xB3],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "ISC".to_string(),
            address: [0x17, 0xB4],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "IPC".to_string(),
            address: [0x17, 0x20],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "ICDM".to_string(),
            address: [0x17, 0xA6],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "ICIMA".to_string(),
            address: [0x14, 0x52],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "ICIMB".to_string(),
        //     address: [0x14, 0x53],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "ISM".to_string(),
        //     address: [0x14, 0x35],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "INV".to_string(),
        //     address: [0x17, 0xE7],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "LBLM".to_string(),
        //     address: [0x14, 0xE5],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "LPDM".to_string(),
            address: [0x14, 0x70],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "LRILM".to_string(),
        //     address: [0x14, 0x94],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "LROLM".to_string(),
        //     address: [0x14, 0x96],
        //     architecture: [].to_vec(),
        // },
        // Ecu {n
        //     name: "".to_string(),
        //     acronym: "LDRM".to_string(),
        //     address: [0x14, 0x87],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "NCM".to_string(),
            address: [0x17, 0x35],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "NFSMB".to_string(),
            address: [0x14, 0x57],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "OMM".to_string(),
            address: [0x17, 0x52],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "OMR".to_string(),
            address: [0x14, 0xE0],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "PBM".to_string(),
            address: [0x17, 0x56],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "PAM".to_string(),
            address: [0x17, 0x36],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "PHCM".to_string(),
        //     address: [0x14, 0x04],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "PBU".to_string(),
            address: [0x14, 0x77],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "PCMB".to_string(),
            address: [0x17, 0x47],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RACM".to_string(),
        //     address: [0x17, 0x74],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RCCD".to_string(),
        //     address: [0x14, 0xF5],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RCCDB".to_string(),
        //     address: [0x14, 0xE7],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RCSSP".to_string(),
        //     address: [0x14, 0x06],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "REM".to_string(),
            address: [0x17, 0x71],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RLD".to_string(),
        //     address: [0x14, 0xF6],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RLPSD".to_string(),
        //     address: [0x14, 0x26],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RLR".to_string(),
        //     address: [0x14, 0xC6],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RLCMA".to_string(),
        //     address: [0x17, 0x17],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RMPU".to_string(),
        //     address: [0x14, 0x43],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RRD".to_string(),
        //     address: [0x14, 0xF7],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RRPSD".to_string(),
        //     address: [0x14, 0x27],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RRR".to_string(),
        //     address: [0x14, 0xC7],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "RDUM".to_string(),
            address: [0x17, 0x05],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RTM".to_string(),
        //     address: [0x14, 0xE1],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "OCS".to_string(),
            address: [0x17, 0x65],
            architecture: [JlrArchitecture::Eva25, JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "RLM".to_string(),
            address: [0x17, 0xD3],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RBLM".to_string(),
        //     address: [0x14, 0xE6],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "RPDM".to_string(),
            address: [0x14, 0x74],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RRILM".to_string(),
        //     address: [0x14, 0x95],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "RROLM".to_string(),
        //     address: [0x14, 0x97],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "RBM".to_string(),
            address: [0x17, 0x66],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "SARM".to_string(),
            address: [0x17, 0x82],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "STAM".to_string(),
        //     address: [0x14, 0x82],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "SCME".to_string(),
            address: [0x17, 0x76],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "SCMF".to_string(),
            address: [0x17, 0x77],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "SCMG".to_string(),
        //     address: [0x17, 0x12],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "SCMH".to_string(),
        //     address: [0x17, 0x13],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "SLR".to_string(),
        //     address: [0x14, 0xD0],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "SRR".to_string(),
        //     address: [0x14, 0xD1],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "SPRM".to_string(),
            address: [0x17, 0x72],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "SBUB".to_string(),
        //     address: [0x14, 0xE3],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "SPBU".to_string(),
        //     address: [0x14, 0x77],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "SGCM".to_string(),
            address: [0x17, 0x80],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "SUMB".to_string(),
            address: [0x17, 0x86],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "TCU".to_string(),
            address: [0x17, 0x54],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "TCUA".to_string(),
        //     address: [0x14, 0xB1],
        //     architecture: [].to_vec(),
        // },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "TCUB".to_string(),
        //     address: [0x14, 0x22],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "TEL".to_string(),
            address: [0x17, 0x81],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "TVM".to_string(),
            address: [0x17, 0x07],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "TPM".to_string(),
            address: [0x17, 0x51],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "TBM".to_string(),
            address: [0x17, 0x57],
            architecture: [JlrArchitecture::Eva2, JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "TRM".to_string(),
            address: [0x17, 0x91],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        // Ecu {
        //     name: "".to_string(),
        //     acronym: "TCCMB".to_string(),
        //     address: [0x14, 0x63],
        //     architecture: [].to_vec(),
        // },
        Ecu {
            name: "".to_string(),
            acronym: "TSCM".to_string(),
            address: [0x14, 0x01],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "VCM".to_string(),
            acronym: "VCM".to_string(),
            address: [0x17, 0xF6],
            architecture: [JlrArchitecture::Eva25].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "VDM".to_string(),
            address: [0x17, 0x21],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
        Ecu {
            name: "".to_string(),
            acronym: "VIM".to_string(),
            address: [0x17, 0x22],
            architecture: [JlrArchitecture::Eva2].to_vec(),
        },
    ];

    list
}
